## cdist-type__cdistmarker(7)

### Daniel Maher

`<phrawzty+cdist--@--gmail.com>`

## 1. NAME

cdist-type__cdistmarker - Add a timestamped cdist marker.

## 2. DESCRIPTION

This type is used to add a common marker file which indicates that a given machine is being managed by cdist. The contents of this file consist of a timestamp, which can be used to determine the most recent time at which cdist was run against the machine in question.

## 3. REQUIRED PARAMETERS

None.

## 4. OPTIONAL PARAMETERS

destination
  The path and filename of the marker. Default: /etc/cdist-configured
format
  The format of the timestamp. This is passed directly to system date. Default: -u

## 5. EXAMPLES

    # Creates the marker as normal.
    __cdistmarker

    # Creates the marker differently.
    __cdistmarker --file /tmp/cdist_marker --format '+%s'

## 6. SEE ALSO

- cdist-type(7)

## 7. COPYING

Copyright (C) 2011 Daniel Maher. Free use of this software is granted under the terms of the GNU General Public License version 3 (GPLv3).